@@ -15,6 +15,7 @@ from .exceptions import (
     IgnoreResultException,
     IgnoreCheckException,
     IncompleteResultException,
+    NoCountException,
 )
 from .logger import setup_logger
 from .net.package import Package
@@ -57,7 +58,9 @@ ASSET_NAME_IDX, CHECK_NAME_IDX = range(2)
 # This is the InfraSonar encryption key used for local configuration files.
 # Note that this is not intended as a real security measure but prevents users
 # from reading a passwords directly from open configuration files.
-FERNET = Fernet(b"4DFfx9LZBPvwvCpwmsVGT_HzjgiGUHduP1kq_L2Fbjw=")
+FERNET = Fernet(bytes(os.getenv(
+    'ENCRYPTION_KEY',
+    '4DFfx9LZBPvwvCpwmsVGT_HzjgiGUHduP1kq_L2Fbjw='), encoding='utf-8'))
 
 MAX_PACKAGE_SIZE = int(os.getenv('MAX_PACKAGE_SIZE', 500))
 if 1 > MAX_PACKAGE_SIZE > 2000:
@@ -223,7 +226,7 @@ class Probe:
         ts = time.time()
 
         logging.debug(f'run check (dry-run); {asset}')
-        success, failed = None, None
+        success, failed, no_count = None, None, False
 
         try:
             try:
@@ -260,6 +263,17 @@ class Probe:
                 f'{asset} error: `{e}` severity: {e.severity}')
             success, failed = e.result, e.to_dict()
 
+        except NoCountException as e:
+            no_count = True
+            if e.severity is None:
+                logging.debug(f'run check ok ({e}); {asset}')
+                success, failed = e.result, None
+            else:
+                logging.warning(
+                    'incomplete no count result; ',
+                    f'{asset} error: `{e}` severity: {e.severity}')
+                success, failed = e.result, e.to_dict()
+
         except CheckException as e:
             logging.error(
                 'check error; '
@@ -269,13 +283,17 @@ class Probe:
             logging.debug(f'run check ok; {asset}')
             success, failed = res, None
 
+        framework = {
+            'duration': time.time() - ts,
+            'timestamp': int(ts),
+        }
+        if no_count:
+            framework['no_count'] = True
+
         response = {
             'result': success,
             'error': failed,
-            'framework': {
-                'duration': time.time() - ts,
-                'timestamp': int(ts),
-            }
+            'framework': framework
         }
         output = json.dumps(response, indent=2)
         print('-'*80, file=sys.stderr)
@@ -317,15 +335,20 @@ class Probe:
             path: tuple,
             result: Optional[dict],
             error: Optional[dict],
-            ts: float):
+            ts: float,
+            no_count: bool = False):
         asset_id, _ = path
+        framework = {
+            'duration': time.time() - ts,
+            'timestamp': int(ts),
+        }
+        if no_count:
+            framework['no_count'] = True
+
         check_data = {
             'result': result,
             'error': error,
-            'framework': {
-                'duration': time.time() - ts,
-                'timestamp': int(ts),
-            }
+            'framework': framework
         }
         pkg = Package.make(
             AgentcoreProtocol.PROTO_FAF_DUMP,
@@ -544,6 +567,16 @@ class Probe:
                     f'{asset} error: `{e}` severity: {e.severity}')
                 self.send(path, e.result, e.to_dict(), ts)
 
+            except NoCountException as e:
+                if e.severity is None:
+                    logging.debug(f'run check ok ({e}); {asset}')
+                    self.send(path, e.result, None, ts, no_count=True)
+                else:
+                    logging.warning(
+                        'incomplete result (no count); ',
+                        f'{asset} error: `{e}` severity: {e.severity}')
+                    self.send(path, e.result, e.to_dict(), ts, no_count=True)
+
             except CheckException as e:
                 logging.error(
                     'check error; '
